@@ -2058,11 +2058,7 @@ void ClipboardBrowserUpdateMenus(clipboard_browser_struct *cb)
 { if(w != NULL) { gtk_widget_set_sensitive(w, sensitivity); } }
 
 #define UPDATE_CHECK_MENU_ITEM_STATE	\
-{ if(w != NULL) {			\
- gtk_check_menu_item_set_active(	\
-  GTK_CHECK_MENU_ITEM(w), state		\
- );					\
-} }
+{ GUIMenuItemSetCheck(w, state, TRUE); }
 
 
 	/* Menu items */
