@@ -1084,6 +1084,7 @@ gint EditorFileSave(
 	mp_header_struct *mp_header;
 	mp_section_struct **mp_section, *mp_section_ptr;
 	gint total_mp_sections;
+	GtkWidget *toplevel;
 	GtkCTree *ctree;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item;
@@ -1100,12 +1101,10 @@ gint EditorFileSave(
 	if(editor->processing)
 	    return(-1);
 
+	toplevel = editor->toplevel;
 	ctree = (GtkCTree *)editor->layout_ctree;
-	if(ctree == NULL)
-	    return(-1);
-
 	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr == NULL)
+	if((ctree == NULL) || (core_ptr == NULL))
 	    return(-1);
 
 	/* Be sure to apply values of currently selected branch (not
@@ -1148,6 +1147,7 @@ gint EditorFileSave(
 			"Write access denied for file:\n\n    %s",
 			filename
 		    );
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponse(
 "Write access denied!",
 			s,
@@ -1158,6 +1158,7 @@ different path.",
 			CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			CDIALOG_BTNFLAG_OK
 		    );
+		    CDialogSetTransientFor(NULL);
 		    g_free(s);
 		    return(-2);
 		}
@@ -1321,17 +1322,17 @@ gint EditorFileSaveAs(
 	GtkCTreeNode *branch    /* Save data on this branch */
 )
 {
+	struct stat stat_buf;
 	gint status;
 	gchar *s;
 	const gchar *cs;
+	GtkWidget *toplevel;
 	GtkCTree *ctree;
 	GtkCTreeRow *branch_row;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item;
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
-	struct stat stat_buf;
-
 
 	if((editor == NULL) || (branch == NULL) || (filename == NULL))
 	    return(-1);
@@ -1339,12 +1340,10 @@ gint EditorFileSaveAs(
 	if(!editor->initialized)
 	    return(-1);
 
+	toplevel = editor->toplevel;
 	ctree = (GtkCTree *)editor->layout_ctree;
-	if(ctree == NULL) 
-	    return(-1);
-
 	core_ptr = MEDIT_CORE(editor->core_ptr);
-	if(core_ptr == NULL)
+	if((ctree == NULL) || (core_ptr == NULL))
 	    return(-1);
 
 	pixmaps_list = &core_ptr->pixmaps_list;
@@ -1393,6 +1392,7 @@ gint EditorFileSaveAs(
 "Overwrite existing file:\n\n    %s",
 		filename
 	    );
+	    CDialogSetTransientFor(toplevel);
 	    status = CDialogGetResponse(
 "Confirm overwrite?",
 		s,
@@ -1406,6 +1406,7 @@ file, if you are unsure say cancel.",
 		CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_CANCEL
 	    );
+	    CDialogSetTransientFor(NULL);
 	    g_free(s);
 
 	    switch(status)
