@@ -344,6 +344,7 @@ void EditorFIPGotoCB(GtkWidget *widget, gpointer data)
 	static gboolean reenterant = FALSE;
 	GtkCList *results_clist;	/* Dialog's results clist */
 	gint row;			/* Row on dialog's result clist */
+	GtkWidget *toplevel;
 	GtkCTree *layout_ctree;
 	GtkCTreeNode *branch;
 	editor_item_struct *item;
@@ -369,7 +370,7 @@ void EditorFIPGotoCB(GtkWidget *widget, gpointer data)
 	    return;
 	}
 
-	/* Get pointer to editor's layout ctree */
+	toplevel = editor->toplevel;
 	layout_ctree = (GtkCTree *)editor->layout_ctree;
 	if(layout_ctree == NULL)
 	{
@@ -408,6 +409,7 @@ void EditorFIPGotoCB(GtkWidget *widget, gpointer data)
 	item = (editor_item_struct *)result_ptr->branch_data;
 	if(item == NULL)
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-Critical Internal error!",
 "Result item structure's pointer to the branch's\n\
@@ -419,6 +421,7 @@ item data.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    reenterant = FALSE;
 	    return;
 	}
@@ -433,6 +436,7 @@ item data.",
 	);
 	if(branch == NULL)
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-Critical Internal error!",
 "Tree branch on the editor's layout tree could not be\n\
@@ -446,6 +450,7 @@ exist on the layout tree.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    reenterant = FALSE;
 	    return;
 	}
