@@ -1013,10 +1013,10 @@ void EditorDoPreview(
 	medit_core_struct *core_ptr;
 	GtkCTreeNode *trunk;
 	editor_item_struct *item;
+	GtkWidget *toplevel;
 	GtkCTree *ctree;
 	gchar *orig_path, *tmp_path, *prog_tmp_path;
 
-
 	if(editor == NULL)
 	    return;
 
@@ -1027,15 +1027,12 @@ void EditorDoPreview(
 	if(editor->processing)   
 	    return;
 
-	core_ptr = (medit_core_struct *)editor->core_ptr;
-	if(core_ptr == NULL)
-	    return;
-
+	toplevel = editor->toplevel;
 	ctree = (GtkCTree *)editor->layout_ctree;
-	if(ctree == NULL)
+	core_ptr = (medit_core_struct *)editor->core_ptr;
+	if((ctree == NULL) || (core_ptr == NULL))
 	    return;
 
-
 	/* Find our editor pointer on core */
 	for(i = 0; i < core_ptr->total_editors; i++)
 	{
@@ -1056,6 +1053,7 @@ void EditorDoPreview(
 "EditorDoPreview(): Viewer number %i is invalid.",
 		viewer_num
 	    );
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-critical internal error!",
 		s,
@@ -1065,6 +1063,7 @@ invalid. Cannot continue with preview.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    g_free(s);
 	    return;
 	}
@@ -1082,6 +1081,7 @@ invalid. Cannot continue with preview.",
 	trunk = EditorItemGetToplevel(editor, branch);
 	if(trunk == NULL)
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-critical internal error!",
 "EditorDoPreview(): Given branch has no trunk.\n",
@@ -1092,6 +1092,7 @@ Cannot continue with preview.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    return;
 	}
 
@@ -1099,6 +1100,7 @@ Cannot continue with preview.",
 	item = EditorBranchGetData(ctree, trunk);
 	if(item == NULL)
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-critical internal error!",
 "EditorDoPreview(): No item data found for given\n\
@@ -1111,6 +1113,7 @@ continue with preview.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    return;
 	}
 
@@ -1121,6 +1124,7 @@ continue with preview.",
 	prog_tmp_path = MEditCreateTempDir(core_ptr);
 	if(prog_tmp_path == NULL)
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-critical internal error!",
 "EditorDoPreview(): MEditCreateTempDir() did not return a path.",
@@ -1131,6 +1135,7 @@ Cannot continue with preview.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	    return;
 	}
 
@@ -1156,7 +1161,7 @@ Cannot continue with preview.",
 	ViewerViewTextRecordScrollPositions(v);
 	ViewerTextDelete(v, 0, -1);
 	ViewerTextInsertPosition(v, 0);
-	status = ViewerLoadFile(
+	status = ViewerOpenFile(
 	    v, item->full_path, orig_path
 	);
 
