@@ -40,6 +40,39 @@
 #ifndef GDK_BUTTON5
 # define GDK_BUTTON5		5
 #endif
+#ifndef GDK_BUTTON6
+# define GDK_BUTTON6		6
+#endif
+#ifndef GDK_BUTTON7
+# define GDK_BUTTON7		7
+#endif
+#ifndef GDK_BUTTON8
+# define GDK_BUTTON8		8
+#endif
+#ifndef GDK_BUTTON9
+# define GDK_BUTTON9		9
+#endif
+#ifndef GDK_BUTTON10
+# define GDK_BUTTON10		10
+#endif
+#ifndef GDK_BUTTON11
+# define GDK_BUTTON11		11
+#endif
+#ifndef GDK_BUTTON12
+# define GDK_BUTTON12		12
+#endif
+#ifndef GDK_BUTTON13
+# define GDK_BUTTON13		13
+#endif
+#ifndef GDK_BUTTON14
+# define GDK_BUTTON14		14
+#endif
+#ifndef GDK_BUTTON15
+# define GDK_BUTTON15		15
+#endif
+#ifndef GDK_BUTTON16
+# define GDK_BUTTON16		16
+#endif
 
 
 /*
@@ -234,6 +267,10 @@ typedef enum {
 /*
  *      GtkWidget Macros:
  */
+#define GTK_WIDGET_REF(_w_)			\
+{ if((_w_) != NULL) gtk_widget_ref(_w_); }
+#define GTK_WIDGET_UNREF(_w_)			\
+{ if((_w_) != NULL) gtk_widget_unref(_w_); }
 #define GTK_WIDGET_SET_SENSITIVE(_w_,_b_)	\
 { if((_w_) != NULL) gtk_widget_set_sensitive((_w_), (_b_)); }
 #define GTK_WIDGET_DESTROY(_w_)			\
@@ -283,10 +320,6 @@ typedef enum {
  (((_w_) != NULL) ? atof(gtk_entry_get_text(GTK_ENTRY(_w_))) : 0.0f)
 
 
-/* Block/Unblock Input */
-extern void GUIBlockInput(GtkWidget *w, gboolean block);
-
-
 /* GtkRcStyle Utilities */
 #if (GTK_MAJOR_VERSION == 1)
 # define gtk_rc_style_copy	GUIRCStyleCopy
@@ -304,7 +337,7 @@ extern GdkGeometryFlags GUIParseGeometry(
 );
 #define gtk_clist_get_cell_geometry	GUICListGetCellGeometry
 extern gboolean GUICListGetCellGeometry(
-	GtkCList *clist, gint column, gint row,
+	GtkCList *clist, const gint column, const gint row,
 	gint *x, gint *y, gint *width, gint *height
 );
 #define gtk_ctree_get_node_row_index	GUICTreeNodeRow
@@ -327,7 +360,7 @@ extern void GUIGetPositionRoot(
 /* String Utilities */
 #define gdk_text_bounds		GUIGetTextBounds
 extern void GUIGetTextBounds(
-	GdkFont *font, const gchar *text, gint text_length,
+	GdkFont *font, const gchar *text, const gint text_length,
 	GdkTextBounds *bounds
 );
 #define gdk_string_bounds	GUIGetStringBounds
@@ -341,6 +374,11 @@ extern void GUIGetStringBounds(
 extern GdkGC *GDK_GC_NEW(void);
 
 
+/* Block/Unblock Input */
+extern void GUIBlockInput(GtkWidget *w, const gboolean block);
+extern gint GUIBlockInputGetLevel(void);
+
+
 /* GdkWindow utilities */
 #define gdk_window_get_ref_count	GUIWindowGetRefCount
 extern gint GUIWindowGetRefCount(GdkWindow *window);
@@ -354,6 +392,8 @@ extern void GUISetWMIconFile(GdkWindow *window, const gchar *filename);
 /* GtkWindow Utilities */
 #define gtk_window_apply_args GUIWindowApplyArgs
 extern void GUIWindowApplyArgs(GtkWindow *w, gint argc, gchar **argv);
+#define gtk_is_window_arg GUIIsWindowArg
+extern gboolean GUIIsWindowArg(const gchar *arg);
 
 
 /* GtkCTree Utilities */
