@@ -677,7 +677,7 @@ gint MEditInit(medit_core_struct *core_ptr, gint argc, gchar **argv)
 		    ViewerSetBusy(viewer);
 		    ViewerTextDelete(viewer, 0, -1);
 		    ViewerTextInsertPosition(viewer, 0);
-		    ViewerLoadFile(viewer, filename, filename);
+		    ViewerOpenFile(viewer, filename, filename);
 		    ViewerSetReady(viewer);
 		}
 	    }
@@ -842,6 +842,7 @@ gint MEditManage(gpointer data)
 	    if(i < core_ptr->total_editors)
 	    {
 		/* Found some changed data that was not saved */
+		CDialogSetTransientFor(NULL);
 		status = CDialogGetResponse(
 "Changes detected!",
 "There are changes to one or more of the editors\n\
@@ -856,6 +857,7 @@ you can say yes to exit and discard those changes.",
 		    CDIALOG_BTNFLAG_HELP,
 		    CDIALOG_BTNFLAG_NO
 		);
+		CDialogSetTransientFor(NULL);
 		switch(status)
 		{
 		  case CDIALOG_RESPONSE_YES:
