@@ -14,17 +14,17 @@
 #include "cdialog.h"
 
 #include "editorfio.h"
-
 #include "manedit.h"
 #include "maneditcb.h"
 #include "maneditop.h"
 #include "aboutdialog.h"
 
+
 #include "images/icon_about_20x20.xpm"
 
 
 GtkWidget *MEditCreateHelpMenu(
-	medit_core_struct *core_ptr, void *accel_group
+	medit_core_struct *core_ptr, GtkAccelGroup *accel_group
 );
 gchar *MEditCreateTempDir(medit_core_struct *core_ptr);
 gint MEditExecuteFmtBlock(
@@ -37,15 +37,23 @@ gint MEditExecuteFmtBlock(
 );
 gint MEditDialogFromFile(
 	medit_core_struct *core_ptr,
-	const gchar *path
+	const gchar *path,
+	GtkWidget *toplevel
 );
 gint MEditDoEmergencySave(medit_core_struct *core_ptr);
 gint MEditDoCrashRecovery(medit_core_struct *core_ptr);
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
 #define MAX(a,b)	(((a) > (b)) ? (a) : (b))
 #define MIN(a,b)	(((a) < (b)) ? (a) : (b))
 #define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 #define ISCR(c)		(((c) == '\n') || ((c) == '\r'))
 
@@ -57,7 +65,7 @@ gint MEditDoCrashRecovery(medit_core_struct *core_ptr);
  *	to add this menu to the menu bar.
  */
 GtkWidget *MEditCreateHelpMenu(
-	medit_core_struct *core_ptr, gpointer accel_group
+	medit_core_struct *core_ptr, GtkAccelGroup *accel_group
 )
 {
 	guint accel_key, accel_mods;
@@ -70,42 +78,38 @@ GtkWidget *MEditCreateHelpMenu(
 	if(core_ptr == NULL)
 	    return(NULL);
 
-#define DO_ADD_MENU_ITEM_LABEL		\
-{ \
- w = GUIMenuItemCreate( \
-  menu, GUI_MENU_ITEM_TYPE_LABEL, accel_group, \
-  icon, label, accel_key, accel_mods, NULL, \
-  client_data, func_cb \
- ); \
+#define DO_ADD_MENU_ITEM_LABEL	{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_LABEL, accel_group,	\
+  icon, label, accel_key, accel_mods, NULL,	\
+  client_data, func_cb				\
+ );						\
 }
 
-#define DO_ADD_MENU_ITEM_SUBMENU	\
-{ \
- w = GUIMenuItemCreate( \
+#define DO_ADD_MENU_ITEM_SUBMENU	{	\
+ w = GUIMenuItemCreate(				\
   menu, GUI_MENU_ITEM_TYPE_SUBMENU, accel_group, \
-  icon, label, accel_key, accel_mods, NULL, \
-  client_data, func_cb \
- ); \
- if(w != NULL) \
-  GUIMenuItemSetSubMenu(w, submenu); \
+  icon, label, accel_key, accel_mods, NULL,	\
+  client_data, func_cb				\
+ );						\
+ if(w != NULL)					\
+  GUIMenuItemSetSubMenu(w, submenu);		\
 }
 
-#define DO_ADD_MENU_ITEM_CHECK		\
-{ \
- w = GUIMenuItemCreate( \
-  menu, GUI_MENU_ITEM_TYPE_CHECK, accel_group, \
-  icon, label, accel_key, accel_mods, NULL, \
-  client_data, func_cb \
- ); \
+#define DO_ADD_MENU_ITEM_CHECK	{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_CHECK, accel_group,	\
+  icon, label, accel_key, accel_mods, NULL,	\
+  client_data, func_cb				\
+ );						\
 }
 
-#define DO_ADD_MENU_SEP			\
-{ \
- w = GUIMenuItemCreate( \
-  menu, GUI_MENU_ITEM_TYPE_SEPARATOR, NULL, \
-  NULL, NULL, 0, 0, NULL, \
-  NULL, NULL \
- ); \
+#define DO_ADD_MENU_SEP		{		\
+ w = GUIMenuItemCreate(				\
+  menu, GUI_MENU_ITEM_TYPE_SEPARATOR, NULL,	\
+  NULL, NULL, 0, 0, NULL,			\
+  NULL, NULL					\
+ );						\
 }
 
 	/* Create help menu */
@@ -169,14 +173,12 @@ gchar *MEditCreateTempDir(medit_core_struct *core_ptr)
 {
 	const gchar *s;
 	gchar *tmp_dir_rtn;
-	pref_struct *pref;
-
 
 	/* Get pointer to pref window, may be NULL */
-	pref = core_ptr->pref;
+	pref_struct *pref = core_ptr->pref;
 
 	/* Allocate and reset tempory directory return to empty */
-	tmp_dir_rtn = g_strdup("");
+	tmp_dir_rtn = STRDUP("");
 
 	/* Get tempory directory prefix */
 	s = PrefParmGetValueP(
@@ -185,8 +187,10 @@ gchar *MEditCreateTempDir(medit_core_struct *core_ptr)
 	if(s == NULL)
 	    s = g_getenv("TMPDIR");
 	if(s == NULL)
-#ifdef P_tmpdir
+#if defined(P_tmpdir)
 	    s = P_tmpdir;
+#elif defined(_WIN32)
+	    s = "C:\\TEMP";
 #else
 	    s = "/tmp";
 #endif
@@ -353,7 +357,8 @@ gint MEditExecuteFmtBlock(
  */
 gint MEditDialogFromFile(
 	medit_core_struct *core_ptr,
-	const gchar *path 
+	const gchar *path,
+	GtkWidget *toplevel
 )
 {
 	gint column, max_columns;
@@ -365,7 +370,6 @@ gint MEditDialogFromFile(
 	gint status = CDIALOG_RESPONSE_NOT_AVAILABLE;
 	struct stat stat_buf;
 
-
 	if((core_ptr == NULL) || (path == NULL))
 	    return(status);
 
@@ -379,19 +383,16 @@ gint MEditDialogFromFile(
 	    /* File does not exist */
 	    return(status);
 	}
-	if(stat_buf.st_size <= 0)
+	if(stat_buf.st_size <= 0l)
 	{
 	    /* File size is 0 bytes */
 	    return(status);
 	}
 
-	/* Open file */
+	/* Open the file for reading */
 	fp = FOpen(path, "rb");
 	if(fp == NULL)
-	{
-	    /* Cannot open file */
 	    return(status);
-	}
 
 	/* Begin reading file */
 	max_columns = 80;
@@ -479,13 +480,11 @@ gint MEditDialogFromFile(
 	if(buf_pos < buf_len)
 	    buf[buf_pos] = '\0';
 
-
-
-	/* Close file */
+	/* Close the file */
 	fclose(fp);
-	fp = NULL;
-
 
+	/* Display the message */
+	CDialogSetTransientFor(toplevel);
 	status = CDialogGetResponse(
 	    "Subsystems Message",
 	    buf,
@@ -494,12 +493,10 @@ gint MEditDialogFromFile(
 	    CDIALOG_BTNFLAG_OK,
 	    CDIALOG_BTNFLAG_OK
 	);
+	CDialogSetTransientFor(NULL);
 
-
-	/* Delete buffer */
+	/* Delete the buffer */
 	g_free(buf);
-	buf_len = 0;
-	buf_pos = 0;
 
 	return(status);
 }
@@ -521,7 +518,7 @@ gint MEditDoEmergencySave(medit_core_struct *core_ptr)
 {
 	gint i;
 	editor_struct *editor;
-	editor_item_struct *item_ptr;
+	editor_item_struct *item;
 	GtkCTreeNode *branch;
 	GtkCTreeRow *branch_row;
 	gchar *prog_tmp_path;
@@ -551,22 +548,22 @@ gint MEditDoEmergencySave(medit_core_struct *core_ptr)
 	    while(branch != NULL)
 	    {
 		/* Get pointer to item data */
-		item_ptr = EditorBranchGetData(
+		item = EditorBranchGetData(
 		    (GtkCTree *)editor->layout_ctree,
 		    branch
 		);
-		if(item_ptr != NULL)
+		if(item != NULL)
 		{
 		    /* Got item, assume it is of type EditorItemTypeFile */
 
 		    /* Change the file name full on this loaded manual
 		     * page to the path specified by tmp_dir
 		     */
-		    g_free(item_ptr->file_name_full);
-		    item_ptr->file_name_full = g_strdup(PrefixPaths(
+		    g_free(item->full_path);
+		    item->full_path = STRDUP(PrefixPaths(
 			prog_tmp_path, "emergencyXXXXXX"
 		    ));
-		    mkstemp(item_ptr->file_name_full);
+		    mkstemp(item->full_path);
 
 		    /* Save this branch */
 		    EditorFileSave(editor, branch);
@@ -648,13 +645,9 @@ gint MEditDoCrashRecovery(medit_core_struct *core_ptr)
 	       strcmp(path_ptr, "..")
 	    )
 	    {
-		gchar *filename = PrefixPaths(prog_tmp_path, path_ptr);
-
-		/* Make a copy of the file name */
-		if(filename != NULL)
-		    filename = g_strdup(filename);
-
-		/* Got filename and confirmation dialog is available? */
+		gchar *filename = STRDUP(
+		    PrefixPaths(prog_tmp_path, path_ptr)
+		);
 		if((filename != NULL) && !CDialogIsQuery())
 		{
 		    gboolean can_remove = FALSE;
@@ -719,27 +712,16 @@ file->save as.",
 			unlink(filename);
 		}
 
-		/* Free file name */
 		g_free(filename);
 	    }
 
-	    /* Delete path */
+	    /* Delete path and go to next path */
 	    g_free(path[i]);
-	    path[i] = NULL;
-
-	    /* Increment to next path */
 	    i++;
 	}
 
-	/* Delete paths pointer array */
 	g_free(path);
-	path = NULL;
-
-
-
-	/* Delete tempory directory */
 	g_free(prog_tmp_path);
-	prog_tmp_path = NULL;
 
 	return(0);
 }
