@@ -572,7 +572,8 @@ gchar *PrefManPageDirPromptBrowseCB(
 {
 	static gboolean reenterant = FALSE;
 	gboolean status;
-	gchar *s, *old_path;
+	gchar *old_path;
+	const gchar *s;
 	fb_type_struct **ext_type;
 	gint total_ext_types; 
 	gchar **path_rtn;
@@ -623,14 +624,12 @@ gchar *PrefManPageDirPromptBrowseCB(
 	{
 	    if(path_total_rtns > 0)
 	    {
-		strncpy(rtn_path, path_rtn[0], PATH_MAX + NAME_MAX);
-		rtn_path[PATH_MAX + NAME_MAX - 1] = '\0';
+		strncpy(rtn_path, path_rtn[0], sizeof(rtn_path));
+		rtn_path[sizeof(rtn_path) - 1] = '\0';
 	    }
 	}
 
-	/* Delete old path */
 	g_free(old_path);
-	old_path = NULL;
 
 	reenterant = FALSE;
 	return(rtn_path);
@@ -646,6 +645,7 @@ void PrefManPageDirsAddCB(GtkWidget *widget, gpointer data)
 	gint row;
 	gchar **response_value;
 	gint total_response_values;
+	GtkWidget *toplevel;
 	GtkCList *clist;
 	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
@@ -656,6 +656,7 @@ void PrefManPageDirsAddCB(GtkWidget *widget, gpointer data)
 	else
 	    reenterant = TRUE;
 
+	toplevel = pref->toplevel;
 	row = pref->selected_manpage_dirs_clist_item;
 
 	clist = (GtkCList *)PrefParmGetWidget(
@@ -730,6 +731,7 @@ void PrefManPageDirsAddCB(GtkWidget *widget, gpointer data)
 			"Warning, directory `%s' does not exist.",
 			response_value[0]
 		    );
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponse(
 "Directory not found!",
 			s,
@@ -740,6 +742,7 @@ correctly.",
 			CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			CDIALOG_BTNFLAG_OK
 		    );
+		    CDialogSetTransientFor(NULL);
 		    g_free(s);
 		}
 	    }
@@ -758,6 +761,7 @@ void PrefManPageDirsEditCB(GtkWidget *widget, gpointer data)
 	gint row;
 	gchar **response_value;
 	gint total_response_values;
+	GtkWidget *toplevel;
 	GtkCList *clist;
 	gchar *cur_path, *cur_label;
 	pref_struct *pref = PREF(data);
@@ -769,6 +773,7 @@ void PrefManPageDirsEditCB(GtkWidget *widget, gpointer data)
 	else
 	    reenterant = TRUE;
 
+	toplevel = pref->toplevel;
 	row = pref->selected_manpage_dirs_clist_item;
 
 	clist = (GtkCList *)PrefParmGetWidget(
@@ -841,6 +846,7 @@ void PrefManPageDirsEditCB(GtkWidget *widget, gpointer data)
 			"Warning, directory `%s' does not exist.",
 			response_value[0]
 		    );
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponse(
 "Directory not found!",
 			s,
@@ -851,6 +857,7 @@ correctly.",
 			CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			CDIALOG_BTNFLAG_OK
 		    );
+		    CDialogSetTransientFor(NULL);
 		    g_free(s);
 		}
 	    }
@@ -870,6 +877,7 @@ void PrefManPageDirsRemoveCB(GtkWidget *widget, gpointer data)
 {
 	static gboolean reenterant = FALSE;
 	gint status, row;
+	GtkWidget *toplevel;
 	GtkCList *clist;
 	pref_struct *pref = PREF(data);
 	if((widget == NULL) || (pref == NULL))
@@ -880,6 +888,7 @@ void PrefManPageDirsRemoveCB(GtkWidget *widget, gpointer data)
 	else
 	    reenterant = TRUE;
 
+	toplevel = pref->toplevel;
 	clist = (GtkCList *)PrefParmGetWidget(
 	    pref, MEDIT_PREF_PARM_LOCATIONS_MAN_DIRS
 	);
@@ -890,6 +899,7 @@ void PrefManPageDirsRemoveCB(GtkWidget *widget, gpointer data)
 	    return;
 	}
 
+	CDialogSetTransientFor(toplevel);
 	status = CDialogGetResponse(
 "Remove Manual Page Directory?",
 "Are you sure you want to remove the selected\n\
@@ -903,6 +913,7 @@ will work with.",
 	    CDIALOG_BTNFLAG_HELP,
 	    CDIALOG_BTNFLAG_NO
 	);
+	CDialogSetTransientFor(NULL);
 	switch(status)
 	{
 	  case CDIALOG_RESPONSE_YES:
