@@ -1,6 +1,6 @@
 #include <string.h>
 #include <ctype.h>
-
+#include <sys/stat.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -14,13 +14,13 @@
 #include "viewercb.h"
 #include "viewerdnd.h"
 #include "editordnd.h"
-
 #include "manedit.h"
 #include "maneditcb.h"
 #include "maneditop.h"
 #include "messages.h"
 #include "config.h"
 
+
 #include "images/manedit_16x16.xpm"
 #include "images/mp_viewer_16x16.xpm"
 #include "images/manedit_20x20.xpm"
@@ -41,10 +41,9 @@
 
 
 viewer_index_item_struct *ViewerIndexItemNew(
-	gint type,	/* One of ViewerIndexItemType* */
-	const gchar *file_name_full 
+	viewer_index_item_type type, const gchar *full_path
 );
-void ViewerIndexItemDelete(viewer_index_item_struct *item_ptr);
+void ViewerIndexItemDelete(viewer_index_item_struct *item);
 void ViewerBranchSelect(
 	viewer_struct *v, GtkCTreeNode *branch
 );
@@ -96,43 +95,51 @@ void ViewerUnmap(viewer_struct *v);
 void ViewerDelete(viewer_struct *v);
 
 
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
+
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
+
+
 #define VIEWER_BTN_WIDTH	(100 + (2 * 3))
 #define VIEWER_BTN_HEIGHT	(30 + (2 * 3))
 
 
-
 /*
- *	Allocates a new viewer index item structure.
+ *	Creates a new Viewer Index Item.
  */
-viewer_index_item_struct *ViewerIndexItemNew(
-	gint type,	/* One of ViewerIndexItemType* */
-	const gchar *file_name_full
+extern viewer_index_item_struct *ViewerIndexItemNew(
+	viewer_index_item_type type, const gchar *full_path
 )
 {
-	viewer_index_item_struct *item_ptr = VIEWER_INDEX_ITEM(g_malloc0(
+	viewer_index_item_struct *item = VIEWER_INDEX_ITEM(g_malloc0(
 	    sizeof(viewer_index_item_struct)
 	));
-	if(item_ptr == NULL)
+	if(item == NULL)
 	    return(NULL);
 
-	item_ptr->type = type;
+	item->type = type;
+	item->full_path = STRDUP(full_path);
 
-	item_ptr->file_name_full = (file_name_full != NULL) ?
-	    g_strdup(file_name_full) : NULL;
-
-	return(item_ptr);
+	return(item);
 }
 
 /*
  *	Deletes a viewer index item structure.
  */
-void ViewerIndexItemDelete(viewer_index_item_struct *item_ptr)
+void ViewerIndexItemDelete(viewer_index_item_struct *item)
 {
-	if(item_ptr == NULL)
+	if(item == NULL)
 	    return;
 
-	g_free(item_ptr->file_name_full);
-	g_free(item_ptr);
+	g_free(item->full_path);
+	g_free(item);
 }
 
 
@@ -462,14 +469,13 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	const gchar *full_path, const gchar *name
 )
 {
+	struct stat stat_buf;
 	gint i, text_total;
 	gchar **text;
-	struct stat stat_buf;
 	GtkCTreeNode *new_branch = NULL;
+	viewer_index_item_struct *item;     
 	medit_core_struct *core_ptr;
 	medit_pixmaps_list_struct *pixmaps_list;
-	viewer_index_item_struct *item_ptr;
-
 
 	/* Check for stop */
 	if(v->stop_count > 0)
@@ -496,14 +502,12 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		/* Allocate name cell value */
 		if(name != NULL)
 		{
-		    text[0] = g_strdup(name);
+		    text[0] = STRDUP(name);
 		}
 		else
 		{
 		    gchar *s = strrchr(full_path, G_DIR_SEPARATOR);
-		    text[0] = g_strdup(
-			(s != NULL) ? (s + 1) : full_path
-		    );
+		    text[0] = STRDUP((s != NULL) ? (s + 1) : full_path);
 		}
 
 		/* Substitute directory name with verbose catagory
@@ -512,42 +516,42 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		if(!strcmp(text[0], "man1"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_1);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_1);
 		}
 		else if(!strcmp(text[0], "man2"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_2);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_2);
 		}
 		else if(!strcmp(text[0], "man3"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_3);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_3);
 		}
 		else if(!strcmp(text[0], "man4"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_4);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_4);
 		}
 		else if(!strcmp(text[0], "man5"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_5);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_5);
 		}
 		else if(!strcmp(text[0], "man6"))
 		{       
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_6);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_6);
 		}
 		else if(!strcmp(text[0], "man7"))
 		{
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_7);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_7);
 		}
 		else if(!strcmp(text[0], "man8"))
 		{ 
 		    g_free(text[0]);
-		    text[0] = g_strdup(MEDIT_SECT_NAME_8);
+		    text[0] = STRDUP(MEDIT_SECT_NAME_8);
 		}
 		/* Now strip .extension from name */
 		if(text[0] != NULL)
@@ -558,11 +562,11 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		}
 
 		/* Allocate lines and read state cell values */
-		text[1] = g_strdup("");
-		text[2] = g_strdup("");
+		text[1] = STRDUP("");
+		text[2] = STRDUP("");
 
 		/* Allocate description value */
-		text[3] = g_strdup("*Directory*");
+		text[3] = STRDUP("*Directory*");
 
 		/* Create new branch */
 		new_branch = gtk_ctree_insert_node(
@@ -578,14 +582,14 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		);
 
 		/* Allocate new index item structure */
-		item_ptr = ViewerIndexItemNew(
+		item = ViewerIndexItemNew(
 		    ViewerIndexItemTypeDirectory,	/* Type */
 		    full_path				/* Full path */
 		);
 		/* Set index item structure pointer to branch row data */
 		gtk_ctree_node_set_row_data_full(
 		    ctree, new_branch,
-		    item_ptr, ViewerIndexBranchDestroyCB
+		    item, ViewerIndexBranchDestroyCB
 		);
 
 		/* Delete cell values */
@@ -600,9 +604,7 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	    {
 		/* Get name cell value */
 		gchar *s = strrchr(full_path, G_DIR_SEPARATOR);
-		text[0] = g_strdup(
-		    (s != NULL) ? (s + 1) : full_path
-		);
+		text[0] = STRDUP((s != NULL) ? (s + 1) : full_path);
 		/* Now strip .extension from name */
 		if(text[0] != NULL)
 		{
@@ -612,11 +614,11 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		}
 
 		/* Get lines and read state cell values */
-		text[1] = g_strdup("");
-		text[2] = g_strdup("");
+		text[1] = STRDUP("");
+		text[2] = STRDUP("");
 
 		/* Get description cell value */
-		text[3] = g_strdup("Manual Page File");
+		text[3] = STRDUP("Manual Page File");
 
 		/* Create new branch */
 		new_branch = gtk_ctree_insert_node(
@@ -632,14 +634,14 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		);
 
 		/* Allocate new index item structure */
-		item_ptr = ViewerIndexItemNew(
+		item = ViewerIndexItemNew(
 		    ViewerIndexItemTypeManualPage,	/* Type */
 		    full_path				/* Full path */
 		);
 		/* Set index item structure pointer to branch row data */
 		gtk_ctree_node_set_row_data_full(
 		    ctree, new_branch,
-		    item_ptr, ViewerIndexBranchDestroyCB
+		    item, ViewerIndexBranchDestroyCB
 		);
 
 		/* Delete cell values */
@@ -651,17 +653,16 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 	/* If given path is a directory, recurse into it */
 	if(S_ISDIR(stat_buf.st_mode))
 	{
-	    gchar *s, **path;
+	    gchar **path;
 
 	    /* Print status message */
-	    s = g_strdup_printf(
+	    gchar *s = g_strdup_printf(
 		"Scanning %s...",
 		full_path
 	    );
 	    ViewerSetStatusMessage(v, s);
 	    g_free(s);
 
-	    /* Manage GTK events */
 	    while(gtk_events_pending() > 0)
 		gtk_main_iteration();
 
@@ -686,10 +687,9 @@ static GtkCTreeNode *ViewerIndexDoLoadIteration(
 		)
 		{
 		    /* Make into full path as strptr */
-		    s = PrefixPaths(full_path, path[i]);
+		    s = STRDUP(PrefixPaths(full_path, path[i]));
 		    if(s != NULL)
 		    {
-			s = (s != NULL) ? g_strdup(s) : NULL;
 			ViewerIndexDoLoadIteration(
 			    v, ctree,
 			    new_branch,		/* Parent */
@@ -1027,8 +1027,6 @@ void ViewerSetBusy(viewer_struct *v)
 
 	gdk_window_set_cursor(w->window, cur);
 	gdk_flush();
-
-	return;   
 }  
 
 /*
@@ -1668,8 +1666,7 @@ viewer_struct *ViewerNew(gpointer core_ptr, gint editor_num)
 }
 
 	/* Toplevel */
-	w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	v->toplevel = w;
+	v->toplevel = w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_widget_realize(w);
 	GUISetWMIcon(w->window, (guint8 **)mp_viewer_48x48_xpm);
 	if(PrefParmGetValueB(pref, MEDIT_PREF_PARM_RECORD_WIN_POS))
@@ -2144,10 +2141,10 @@ viewer_struct *ViewerNew(gpointer core_ptr, gint editor_num)
 	    dnd_src_types,
 	    sizeof(dnd_src_types) / sizeof(GtkTargetEntry),
 	    GDK_ACTION_COPY,			/* Actions */
-	    GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,/* Buttons */
+	    GDK_BUTTON1_MASK,			/* Buttons */
 	    NULL,
 	    ViewerIndexCTreeDNDDataRequestCB,
-	    ViewerDNDDataDeleteCB,		/* Does nothing */
+	    ViewerDNDDataDeleteCB,
 	    NULL,
 	    v
 	);
@@ -2295,7 +2292,7 @@ void ViewerUpdateMenus(viewer_struct *v)
 	medit_core_struct *core_ptr;
 	GtkCTreeRow *branch_row;
 	gboolean sensitivity, state;
-	viewer_index_item_struct *item_ptr;
+	viewer_index_item_struct *item;
 	gint toolbar_btn_layout = 2;
 
 	if(v == NULL)
@@ -2314,43 +2311,29 @@ void ViewerUpdateMenus(viewer_struct *v)
 	    reenterant = TRUE;
 
 
-#define SET_WIDGET_SENSITIVITY		\
-{ \
- if(w != NULL) \
-  gtk_widget_set_sensitive(w, sensitivity); \
+#define SET_WIDGET_SENSITIVITY		{	\
+ if(w != NULL)					\
+  gtk_widget_set_sensitive(w, sensitivity);	\
 }
-
-#define SET_CHECK_MENU_ITEM_STATE	\
-{ \
- if(w != NULL) \
-  gtk_check_menu_item_set_active( \
-   GTK_CHECK_MENU_ITEM(w), \
-   state \
-  ); \
+#define SET_CHECK_MENU_ITEM_STATE	{	\
+ GUIMenuItemSetCheck(w, state, TRUE);		\
 }
-
-#define SET_BUTTON_LAYOUT		\
-{ \
- if(w != NULL) \
- { \
-  switch(toolbar_btn_layout) \
-  { \
-   case 2: \
-    GUIButtonChangeLayout(w, 1, 1); \
-    gtk_widget_set_usize(w, 60, 50); \
-    break; \
-   case 1: \
-    GUIButtonChangeLayout(w, 1, 0); \
-    gtk_widget_set_usize(w, 30, 30); \
-    break; \
-   default: \
-    GUIButtonChangeLayout(w, 0, 1); \
-    gtk_widget_set_usize(w, -1, 30); \
-    break; \
-  } \
- } \
-}
-
+#define SET_BUTTON_LAYOUT		{	\
+ if(w != NULL) {				\
+  switch(toolbar_btn_layout) {			\
+   case 2:					\
+    GUIButtonChangeLayout(w, 1, 1);		\
+    gtk_widget_set_usize(w, 60, 50);		\
+    break;					\
+   case 1:					\
+    GUIButtonChangeLayout(w, 1, 0);		\
+    gtk_widget_set_usize(w, 30, 30);		\
+    break;					\
+   default:					\
+    GUIButtonChangeLayout(w, 0, 1);		\
+    gtk_widget_set_usize(w, -1, 30);		\
+    break;					\
+} } }
 
 	/* Get tool bar button display type */
 	if(PrefParmGetValueB(
@@ -2365,7 +2348,7 @@ void ViewerUpdateMenus(viewer_struct *v)
 	    toolbar_btn_layout = 0;
 
 
-/* Need to update title */
+/* TODO: Update title */
 
 
 	/* File menu */
@@ -2381,11 +2364,11 @@ void ViewerUpdateMenus(viewer_struct *v)
 	menu = v->view_mh;
 	{
 	    w = v->view_view_mi;
-	    state = ((v->current_page == ViewerPageNumView) ? TRUE : FALSE);
+	    state = (v->current_page == ViewerPageNumView) ? TRUE : FALSE;
 	    SET_CHECK_MENU_ITEM_STATE
 
 	    w = v->view_index_mi;
-	    state = ((v->current_page == ViewerPageNumIndex) ? TRUE : FALSE);
+	    state = (v->current_page == ViewerPageNumIndex) ? TRUE : FALSE;
 	    SET_CHECK_MENU_ITEM_STATE
 	}
 
@@ -2411,34 +2394,32 @@ void ViewerUpdateMenus(viewer_struct *v)
 	    else
 		branch_row = GTK_CTREE_ROW(v->selected_index_branch);
 	    w = v->index_parent_mi;
-	    sensitivity = ((branch_row == NULL) ? 
-		FALSE : (branch_row->parent != NULL)
-	    );
+	    sensitivity = (branch_row != NULL) ?
+		(branch_row->parent != NULL) : FALSE;
 	    SET_WIDGET_SENSITIVITY  
 
 	    if((v->index_ctree != NULL) &&
 	       (v->selected_index_branch != NULL)
 	    )
-		item_ptr = (gpointer)gtk_ctree_node_get_row_data(
-		    (GtkCTree *)v->index_ctree,
-		    v->selected_index_branch
-		);
+		item = VIEWER_INDEX_ITEM(gtk_ctree_node_get_row_data(
+		    GTK_CTREE(v->index_ctree), v->selected_index_branch
+		));
 	    else
-		item_ptr = NULL;
+		item = NULL;
 	    w = v->index_expand_mi;
-	    if(item_ptr == NULL)
+	    if(item == NULL)
 		sensitivity = FALSE;
-	    else if(item_ptr->type == ViewerIndexItemTypeDirectory)
+	    else if(item->type == ViewerIndexItemTypeDirectory)
 		sensitivity = TRUE;
 	    else
 		sensitivity = FALSE;
 	    SET_WIDGET_SENSITIVITY
 
 	    w = v->index_goto_mi;
-	    if(item_ptr == NULL)
+	    if(item == NULL)
 		sensitivity = FALSE;
-	    else if((item_ptr->type == ViewerIndexItemTypeManualPage) ||
-		    (item_ptr->type == ViewerIndexItemTypeOtherFile)
+	    else if((item->type == ViewerIndexItemTypeManualPage) ||
+		    (item->type == ViewerIndexItemTypeOtherFile)
 	    )
 		sensitivity = TRUE;
 	    else
@@ -2487,17 +2468,16 @@ void ViewerUpdateMenus(viewer_struct *v)
 	if((v->index_ctree != NULL) &&
 	   (v->selected_index_branch != NULL)
 	)
-	    item_ptr = (gpointer)gtk_ctree_node_get_row_data(
-		(GtkCTree *)v->index_ctree,
-		v->selected_index_branch
-	    );
+	    item = VIEWER_INDEX_ITEM(gtk_ctree_node_get_row_data(
+		GTK_CTREE(v->index_ctree), v->selected_index_branch
+	    ));
 	else
-	    item_ptr = NULL;
+	    item = NULL;
 	w = v->index_goto_btn;
-	if(item_ptr == NULL)
+	if(item == NULL)
 	    sensitivity = FALSE;
-	else if((item_ptr->type == ViewerIndexItemTypeManualPage) ||
-		(item_ptr->type == ViewerIndexItemTypeOtherFile)
+	else if((item->type == ViewerIndexItemTypeManualPage) ||
+		(item->type == ViewerIndexItemTypeOtherFile)
 	)
 	    sensitivity = TRUE;
 	else
@@ -2509,13 +2489,11 @@ void ViewerUpdateMenus(viewer_struct *v)
 	SET_WIDGET_SENSITIVITY
 
 
-
 #undef SET_WIDGET_SENSITIVITY
 #undef SET_CHECK_MENU_ITEM_STATE
 #undef SET_BUTTON_LAYOUT
 
 	reenterant = FALSE;
-	return;
 }
 
 
@@ -2699,7 +2677,7 @@ void ViewerRecordPositions(viewer_struct *v)
 	    if(v->last_open_path != NULL)
 	    {
 		g_free(pref->last_opened_manage_view_path);
-		pref->last_opened_manage_view_path = g_strdup(
+		pref->last_opened_manage_view_path = STRDUP(
 		    v->last_open_path
 		);
 	    }
@@ -2828,12 +2806,10 @@ void ViewerReset(viewer_struct *v, gboolean need_unmap)
 	v->cur_manpage_name = NULL;
 
 	/* Get paths */
-	if((pref == NULL) ?
-	    0 : (pref->last_opened_manage_view_path != NULL)
-	)
+	if(pref != NULL)
 	{
 	    g_free(v->last_open_path);
-	    v->last_open_path = g_strdup(pref->last_opened_manage_view_path);
+	    v->last_open_path = STRDUP(pref->last_opened_manage_view_path);
 	}
 
 	/* Reset status messages */
@@ -2841,12 +2817,10 @@ void ViewerReset(viewer_struct *v, gboolean need_unmap)
 	ViewerSetStatusMessage(v, NULL);
 	ViewerSetStatusProgress(v, 0.0);
 
-
 	/* Clear view text */
 	ViewerTextDelete(v, 0, -1);
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
