@@ -211,14 +211,9 @@ void ViewerSwitchPageCB(
 	 * page changed now since this callback is called just before
 	 * the page is changed.
 	 */
-	gtk_timeout_add(
-	    0,
-	    (GtkFunction)ViewerPageChangedTOCB,
-	    (gpointer)v
-	);
+	gtk_idle_add(ViewerPageChangedTOCB, v);
 
 	reenterant = FALSE;
-	return;
 }
 
 /*
@@ -285,13 +280,12 @@ gint ViewerPageChangedTOCB(gpointer data)
 	switch(v->current_page)
 	{
 	  case ViewerPageNumView:
-
 	    break;
 
 	  case ViewerPageNumIndex:
 	    ctree = (GtkCTree *)v->index_ctree;
-	    if((ctree == NULL) ?
-		0 : (gtk_ctree_node_nth(ctree, 0) == NULL)
+	    if((ctree != NULL) ?
+		(gtk_ctree_node_nth(ctree, 0) == NULL) : FALSE
 	    )
 	    {
 		ViewerIndexRefreshCB(v->index_refresh_btn, data);
@@ -452,9 +446,10 @@ void ViewerIndexBranchExpandCB(GtkWidget *widget, gpointer data)
 void ViewerOpenCB(GtkWidget *widget, gpointer data)
 {
 	gint status;
+	GtkWidget *toplevel;
+	GtkText *text;
 	medit_core_struct *core_ptr;
 	medit_fetype_list_struct *fetype_list;
-	GtkText *text;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
 	    return;
@@ -466,12 +461,10 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 	if(v->processing)
 	    return;
 
-	core_ptr = (medit_core_struct *)v->core_ptr;
-	if(core_ptr == NULL)
-	    return;
-
+	toplevel = v->toplevel;
 	text = (GtkText *)v->view_text;
-	if(text == NULL)
+	core_ptr = (medit_core_struct *)v->core_ptr;
+	if((text == NULL) || (core_ptr == NULL))
 	    return;
 
 	fetype_list = &core_ptr->fetype_list;
@@ -501,7 +494,7 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 /*		    ViewerViewTextRecordScrollPositions(v); */
 		    ViewerTextDelete(v, 0, -1);
 		    ViewerTextInsertPosition(v, 0);
-		    status = ViewerLoadFile(v, path_rtn[0], path_rtn[0]);
+		    status = ViewerOpenFile(v, path_rtn[0], path_rtn[0]);
 		    ViewerSetReady(v);
 
 		    switch(status)
@@ -516,6 +509,7 @@ void ViewerOpenCB(GtkWidget *widget, gpointer data)
 "Could not find the manual page file:\n\n    %s",
 			    path_rtn[0]
 			);
+			CDialogSetTransientFor(toplevel);
 			CDialogGetResponse(
 			    "Manual page not found!",
 			    s,
@@ -526,11 +520,13 @@ read permissions set.",
 			    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 			    CDIALOG_BTNFLAG_OK
 			);
+			CDialogSetTransientFor(NULL);
 			g_free(s);
 			break;   
 		       
 		      /* Other error */
 		      default:
+			CDialogSetTransientFor(toplevel);
 			CDialogGetResponse(
 "Manual page opening error!",
 "Error occured while opening manual page.",
@@ -538,7 +534,8 @@ read permissions set.",
 			    CDIALOG_ICON_ERROR,
 			    CDIALOG_BTNFLAG_OK,
 			    CDIALOG_BTNFLAG_OK
-			);  
+			);
+			CDialogSetTransientFor(NULL);
 			break;
 		    }
 		}
@@ -716,7 +713,7 @@ void ViewerGotoCB(GtkWidget *widget, gpointer data)
 		ViewerViewTextRecordScrollPositions(v);
 		ViewerTextDelete(v, 0, -1);
 		ViewerTextInsertPosition(v, 0);
-		ViewerLoadFile(
+		ViewerOpenFile(
 		    v, item->full_path, item->full_path
 		);
 		ViewerSetReady(v);
@@ -988,6 +985,7 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 	static gboolean reenterant = FALSE;
 	gint section = -2;	/* Any */
 	gchar *s, *name, *search_string;
+	GtkWidget *toplevel;
 	GtkCombo *combo;
 	viewer_struct *v = VIEWER(data);
 	if(v == NULL)
@@ -1002,6 +1000,7 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 	    reenterant = TRUE;
 
 	/* Get manpage combo */
+	toplevel = v->toplevel;
 	combo = (GtkCombo *)v->manpage_combo;
 	if(combo == NULL)
 	{
@@ -1095,6 +1094,7 @@ void ViewerManPageActivateCB(GtkWidget *widget, void *data)
 	     */
 	    if(*search_string != G_DIR_SEPARATOR)
 	    {
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Invalid path!",
 "When specifying an exact manual page, the path must be\n\
@@ -1106,7 +1106,7 @@ matches.",
 		    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		    CDIALOG_BTNFLAG_OK
 		);
-
+		CDialogSetTransientFor(NULL);
 		g_free(search_string);
 		g_free(name);
 		reenterant = FALSE;
@@ -1136,7 +1136,7 @@ matches.",
 	ViewerViewTextRecordScrollPositions(v);
 	ViewerTextDelete(v, 0, -1);
 	ViewerTextInsertPosition(v, 0);
-	ViewerLoadFile(v, search_string, name);
+	ViewerOpenFile(v, search_string, name);
 	ViewerSetReady(v);
 
 	g_free(search_string);
@@ -1158,13 +1158,14 @@ static void ViewerDoFindCB(
 	gboolean got_match, search_wrapped;
 	gint start_pos;
 	gchar *haystack = NULL, *needle = NULL;
+	GtkWidget *toplevel;
 	GtkEditable *editable;
 	GtkText *text; 
 
 	if((v == NULL) || (find_combo == NULL))
 	    return;
 
-	/* Get pointer to view text */
+	toplevel = v->toplevel;
 	text = (GtkText *)v->view_text;
 	if(text == NULL)
 	    return;
@@ -1196,6 +1197,8 @@ static void ViewerDoFindCB(
 	{
 	    /* Search wrapped? */
 	    if(search_wrapped)
+	    {
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Search wrapped!",
 "Search wrapped!",
@@ -1206,9 +1209,12 @@ was matched after the cursor position.",
 		    CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		    CDIALOG_BTNFLAG_OK
 		);
+		CDialogSetTransientFor(NULL);
+	    }
 	}   
 	else
 	{
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "String not found!",
 "String not found!",
@@ -1219,6 +1225,7 @@ does not exist in the text.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
+	    CDialogSetTransientFor(NULL);
 	}
 
 	g_free(haystack);
