@@ -449,7 +449,7 @@ void ViewerViewTextDNDDataRecievedCB(
 			    ViewerViewTextRecordScrollPositions(v);
 			    ViewerTextDelete(v, 0, -1);
 			    ViewerTextInsertPosition(v, 0);
-			    ViewerLoadFile(
+			    ViewerOpenFile(
 				v,
 				item->full_path,
 				item->full_path
@@ -492,7 +492,7 @@ void ViewerViewTextDNDDataRecievedCB(
 		ViewerViewTextRecordScrollPositions(v);
 		ViewerTextDelete(v, 0, -1);
 		ViewerTextInsertPosition(v, 0);
-		ViewerLoadFile(v, path, path);
+		ViewerOpenFile(v, path, path);
 		ViewerSetReady(v);
 
 		g_free(path);
