@@ -20,7 +20,7 @@
 
 
 static gint ViewerLoadProgressCB(glong cur, glong max, gpointer data);
-gint ViewerLoadFile(
+gint ViewerOpenFile(
 	viewer_struct *v, const gchar *filename, const gchar *name
 );
 
@@ -65,7 +65,7 @@ static gint ViewerLoadProgressCB(glong cur, glong max, void *data)
  *
  *	Returns non-zero on error.
  */
-gint ViewerLoadFile(
+gint ViewerOpenFile(
 	viewer_struct *v, const gchar *filename, const gchar *name
 )
 {
@@ -79,6 +79,7 @@ gint ViewerLoadFile(
 	gchar *stderr_path;
 	const gchar *converter_cmd;
 	GtkAdjustment *vadj;
+	GtkWidget *toplevel;
 
 	medit_core_struct *core_ptr;
 	struct stat stat_buf;
@@ -97,6 +98,8 @@ gint ViewerLoadFile(
 	/* Mark as processing */
 	v->processing = TRUE;
 
+	toplevel = v->toplevel;
+
 	/* If given filename is an absolute path, then check if it
 	 * exists. This is to allow the converter program to search for
 	 * relative paths
@@ -125,7 +128,7 @@ gint ViewerLoadFile(
 	if((converter_cmd == NULL) ? 1 : ((*converter_cmd) == '\0'))
 	{
 	    v->processing = FALSE;
-
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Command not defined!",
 "Manual Page to output converter command is not\n\
@@ -139,7 +142,7 @@ this command under edit->preferences->converters.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
-
+	    CDialogSetTransientFor(NULL);
 	    return(-1);
 	}
 
@@ -149,6 +152,8 @@ this command under edit->preferences->converters.",
 	prog_tmp_dir = MEditCreateTempDir(core_ptr);
 	if(prog_tmp_dir == NULL)
 	{
+	    v->processing = FALSE;
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 "Non-critical internal error!",
 "EditorDoPreview(): MEditCreateTempDir() did not return a path.",
@@ -159,7 +164,7 @@ Cannot continue with preview.",
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
 		CDIALOG_BTNFLAG_OK
 	    );
-	    v->processing = FALSE;
+	    CDialogSetTransientFor(NULL);
 	    return(-1);
 	}
 
@@ -213,7 +218,7 @@ Cannot continue with preview.",
 	ViewerSetStatusMessage(v, "Convert done");
 
 	/* If stderr_path exists, notify of error */
-	MEditDialogFromFile(core_ptr, stderr_path);
+	MEditDialogFromFile(core_ptr, stderr_path, toplevel);
 
 
 	/* Begin loading tempory output file */
