@@ -9,7 +9,7 @@
 #include "viewer.h"
 
 
-extern gint ViewerLoadFile(
+extern gint ViewerOpenFile(
 	viewer_struct *v, const gchar *filename, const gchar *name
 );
 
